#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 input-parsers
version:              0.2.2
visibility:           public
id:                   input-parsers-0.2.2-F8ZkLuB7fO2CLH36vofCoy
key:                  input-parsers-0.2.2-F8ZkLuB7fO2CLH36vofCoy
license:              BSD-3-Clause
copyright:            (c) 2020 Mario Blažević
maintainer:           blamario@protonmail.com
author:               Mario Blažević
synopsis:
    Extension of the parsers library with more capability and efficiency

description:
    Extended version of the parsers library, with the additional classes providing more
    capable and efficient methods.

category:             Parsing
abi:                  a72d477a9b72785f02046803a13ff409
exposed:              True
exposed-modules:
    Text.Parser.Deterministic Text.Parser.Input
    Text.Parser.Input.Position Text.Parser.Wrapper

hidden-modules:       Text.Parser.Internal
import-dirs:          /usr/lib/ghc-8.10.5/site-local/input-parsers-0.2.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/input-parsers-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/input-parsers-0.2.2
hs-libraries:         HSinput-parsers-0.2.2-F8ZkLuB7fO2CLH36vofCoy
depends:
    base-4.14.2.0 binary-0.8.8.0 bytestring-0.10.12.0
    monoid-subclasses-1.1-AwFjCNwVwkv9V7v1aD1jp3 parsec-3.1.14.0
    parsers-0.12.10-DGz13yHc7wxB3ssNjoRPte text-1.2.4.1
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-input-parsers/html/input-parsers.haddock

haddock-html:         /usr/share/doc/haskell-input-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

